/* ====================================================================
   Copyright 2005   Apache Software Foundation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.hssf.record.formula;

import org.apache.poi.util.LittleEndian;

import org.apache.poi.hssf.util.CellReference;
import org.apache.poi.hssf.model.Workbook;

/**
 * RefErrPtg - handles deleted references
 * @author  Andrew C. Oliver (acoliver@apache.org)
 * @author Jason Height (jheight at chariot dot net dot au)
 * @author Peter Wooster (pkwooster at gmail dot com)
 */

public class RefErrPtg extends Ptg
{
    private final static int SIZE = 5;
    public final static byte sid  = 0x2a; // from openoffice.org excelfileformat
    
    private short            field_1_row;
    private short            field_2_col;
    
    private RefErrPtg() {
      //Required for clone methods
    }
    

    public RefErrPtg(byte[] data, int offset) {
        offset++;   // adjust for ptg
        field_1_row = LittleEndian.getShort(data, offset + 0);
        field_2_col = LittleEndian.getShort(data, offset + 2);
    }

    public String toString() {
        return "#RefErr:"+field_1_row+","+field_2_col;
    }

    public void writeBytes(byte [] array, int offset) {
        array[offset] = (byte) (sid + ptgClass);
        LittleEndian.putShort(array,offset+1,field_1_row);
        LittleEndian.putShort(array,offset+3,field_2_col);
    }

    public int getSize() {
        return SIZE;
    }

    public String toFormulaString(Workbook book) {
        return "#REF";
    }
    
    public byte getDefaultOperandClass() {
        return Ptg.CLASS_REF;
    }
    
    public Object clone() {
      RefErrPtg ptg = new RefErrPtg();
      ptg.field_1_row = field_1_row;
      ptg.field_2_col = field_2_col;
      ptg.setClass(ptgClass);
      return ptg;
    }
}
